@@ -1,5 +1,5 @@
 # msap - Statistical analysis for Methilation-Sensitive Amplification Polimorphism data
-# version: 1.1.3
+# version: 1.1.4
 # Author: Andrés Pérez-Figueroa (anpefi@uvigo.es)
 
 
@@ -7,7 +7,7 @@
 
 msap <- function(datafile, name=datafile, no.bands="u", nDec=4, meth=TRUE, rm.redundant=TRUE, rm.monomorphic=TRUE, do.pcoa=TRUE, do.shannon=TRUE, do.amova=TRUE, do.pairwisePhiST=TRUE, do.cluster=TRUE, use.groups=NULL, do.mantel=FALSE, np.mantel=1000, loci.per.primer=NULL, error.rate.primer=NULL, uninformative=TRUE){
 	
-	cat("\nmsap 1.1.3 - Statistical analysis for Methylation-Sensitive Amplification Polimorphism data\n")
+	cat("\nmsap 1.1.4 - Statistical analysis for Methylation-Sensitive Amplification Polimorphism data\n")
 	 
 	 ########## CHECKING PARAMETERS ############
 	
@@ -183,11 +183,11 @@ msap <- function(datafile, name=datafile, no.bands="u", nDec=4, meth=TRUE, rm.re
 		#save transformed files (MSL and NML)
 		if(MSL.nloci>0){
 			cat("- Saving transformed matrix for MSL in file: ",paste(name,"-MSL-transformed.csv",sep=""),"\n")
-		 	write.csv(data.frame(groups,inds,matM), file=paste(name,"-MSL-transformed.csv"), row.names=FALSE)
+		 	write.csv(data.frame(groups,inds,matM), file=paste(name,"-MSL-transformed.csv",sep=""), row.names=FALSE)
 		}
 		if(NML.nloci>0){
 			cat("- Saving transformed matrix for NML in file: ",paste(name,"-NML-transformed.csv",sep=""),"\n")
-			write.csv(data.frame(groups,inds,matM), file=paste(name,"-NML-transformed.csv"), row.names=FALSE)
+			write.csv(data.frame(groups,inds,matN), file=paste(name,"-NML-transformed.csv",sep=""), row.names=FALSE)
 		}
 		if(MSL.nloci>0) MSL.I <- apply(matM, 2, shannon)
 		if(NML.nloci>0) NML.I <- apply(matN, 2, shannon)
@@ -207,7 +207,7 @@ msap <- function(datafile, name=datafile, no.bands="u", nDec=4, meth=TRUE, rm.re
 		if(MSL.nloci>0){
 		
 			cat("\n\n*****************************\nAnalysis of MSL\n")
-			repMet(dataMIX[,MSL], groups, nDec)
+			meth.rep <- repMet(dataMIX[,MSL], groups, nDec)
 		  cat("\n\n")
 	
 			DM<-lingoes(as.dist(smc(matM, dist=TRUE))) #Simple Matching Coefficient, from scrime
@@ -336,12 +336,13 @@ msap <- function(datafile, name=datafile, no.bands="u", nDec=4, meth=TRUE, rm.re
   #Storing some interesting item in a list to be returned (as suggested by C. Herrera)
 	res <- list(
     groups = if(exists("groups")) {groups} else {NULL},
+    patterns = if(exists("meth.rep")) {meth.rep} else {NULL},
     transformed.MSL = if(MSL.nloci>0) {data.frame(groups,inds,matM)} else {NULL},
     transformed.NML = if(NML.nloci>0) {data.frame(groups,inds,matN)} else {NULL},
     DM.MSL = if(exists("DM.MSL")) {DM.MSL} else {NULL},
     DM.NML = if(exists("DM.NML")) {DM.NML} else {NULL},
     DM.AFLP = if(exists("DM.AFLP")) {DM.AFLP} else {NULL}
-    )
+     )
   
 	 cat("Done!\n")
    invisible(res)
